summaryrefslogtreecommitdiffstats
path: root/src/display
diff options
context:
space:
mode:
Diffstat (limited to 'src/display')
-rw-r--r--src/display/nr-arena-shape.cpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/display/nr-arena-shape.cpp b/src/display/nr-arena-shape.cpp
index afc30acb8..6aa259ba6 100644
--- a/src/display/nr-arena-shape.cpp
+++ b/src/display/nr-arena-shape.cpp
@@ -379,11 +379,12 @@ nr_arena_shape_update(NRArenaItem *item, NRRectL *area, NRGC *gc, guint state, g
}
item->render_opacity = FALSE;
}
- if ( item->render_opacity == TRUE
- && shape->_fill.paint.type() != NRArenaShape::Paint::NONE
- && shape->_stroke.paint.type() != NRArenaShape::Paint::NONE )
+ if ( (shape->_fill.paint.type() != NRArenaShape::Paint::NONE &&
+ shape->_stroke.paint.type() != NRArenaShape::Paint::NONE)
+ || (shape->markers)
+ )
{
// don't merge item opacity with paint opacity if there is a stroke on the fill
item->render_opacity = FALSE;
}
@@ -379,11 +379,12 @@ nr_arena_shape_update(NRArenaItem *item, NRRectL *area, NRGC *gc, guint state, g
{
- // don't merge item opacity with paint opacity if there is a stroke on the fill
+ // don't merge item opacity with paint opacity if there is a stroke on the fill, or markers on stroke
item->render_opacity = FALSE;
}